-- variables given in comments with '\set' have to be given
-- to psql via the -v flag:
-- \set min_a '(SELECT min(a) FROM ranges)';
-- \set max_b '(SELECT max(b) FROM ranges)';
-- \set elev random();
-- \set qfac (0.5+random());
-- \set vfac 10+10*random();
-- \set sfac 10+10*random();

\set ON_ERROR_STOP true;

-- change name of river
UPDATE rivers SET name = 'Beispielfluss';
\c seddb_demodata
UPDATE gewaesser SET name = 'Beispielfluss';
\c d4e_demodata

-- shift stations to start at minimum station
-- \set min_a '(SELECT min(a) FROM ranges)';
-- \set max_b '(SELECT max(b) FROM ranges)';
-- the two UPDATEs on some tables (+:max_b and -(:max_b+:min_a))
-- are necessary to circumvent PostgreSQLs non-standard behaviour
-- regarding the checking of UNIQUE-constraints
-- (see the Compatibility section in the manual for CREATE TABLE)
BEGIN;
UPDATE gauges SET station = station + :max_b;
UPDATE gauges SET station = station - (:max_b + :min_a);
UPDATE wst_column_values SET position = position + :max_b;
UPDATE wst_column_values SET position = position - (:max_b + :min_a);
UPDATE cross_section_lines SET km = km + :max_b;
UPDATE cross_section_lines SET km = km - (:max_b + :min_a);
UPDATE hyk_entries SET km = km + :max_b;
UPDATE hyk_entries SET km = km - (:max_b + :min_a);
UPDATE river_axes_km SET km = km - :min_a;
UPDATE cross_section_tracks SET km = km - :min_a;
UPDATE buildings SET km = km - :min_a;
UPDATE fixpoints SET km = km - :min_a;
UPDATE jetties SET km = km - :min_a;
UPDATE flood_marks SET km = km - :min_a;
UPDATE bed_height_single_values SET station = station + :max_b;
UPDATE bed_height_single_values SET station = station - (:max_b + :min_a);
UPDATE bed_height_epoch_values SET station = station - :min_a;
UPDATE sediment_density_values SET station = station - :min_a;
UPDATE morphologic_width_values SET station = station - :min_a;
UPDATE flow_velocity_model_values SET station = station + :max_b;
UPDATE flow_velocity_model_values 
    SET station = station - (:max_b + :min_a);
UPDATE flow_velocity_measure_values SET station = station - :min_a;
UPDATE sediment_yield_values SET station = station - :min_a;
UPDATE measurement_station SET station = station - :min_a;
UPDATE ranges SET (b,a) = (b + :max_b, a + :max_b);
UPDATE ranges SET (b,a) = (b - (:max_b + :min_a), a - (:max_b + :min_a));
COMMIT;

\c seddb_demodata
--SET search_path TO seddb;
BEGIN;
UPDATE bezugspegel SET km = km - :min_a;
UPDATE hpeilung SET km = km - :min_a;
UPDATE messung SET km = km - :min_a;
UPDATE station SET km = km - :min_a;
UPDATE mpeilung SET km = km - :min_a;
UPDATE sohltest SET km = km - :min_a;
COMMIT;
\c d4e_demodata;

-- lift elevation values to somewhere between 0 and 1 m higher
-- \set elev random();
BEGIN;
UPDATE gauges SET datum = datum + :elev;
UPDATE wst_column_values SET w = w + :elev;
UPDATE cross_section_points SET y = y + :elev;
UPDATE cross_section_tracks SET z = z + :elev;
UPDATE hws_points SET (z, z_target, rated_level) = 
    (z + :elev, z_target + :elev, rated_level + :elev);
UPDATE jetties SET z = z + :elev;
UPDATE flood_marks SET z = z + :elev;
UPDATE bed_height_single_values SET height = height + :elev;
UPDATE bed_height_epoch_values SET height = height + :elev;
UPDATE flow_velocity_measure_values SET w = w + :elev;
COMMIT;

-- alter Q values to tamper WQ and SQ relations
-- \set qfac (0.5+random());
BEGIN;
UPDATE main_values SET value = value*:qfac WHERE id IN (
    SELECT mv.id FROM main_values mv 
            JOIN named_main_values nmv ON nmv.id=named_value_id
            JOIN main_value_types mvt ON type_id=mvt.id
        WHERE mvt.name IN ('Q', 'D'));
UPDATE discharge_table_values SET q = q*:qfac;
UPDATE wst_q_ranges SET q = q*:qfac;
UPDATE discharge_zone SET value = value*:qfac;
UPDATE flow_velocity_model_values SET q = q*:qfac;
UPDATE flow_velocity_measure_values SET q = q*:qfac;
UPDATE sq_relation_value SET (a, qmax) = (a/:qfac^b, qmax*:qfac);
COMMIT;

\c seddb_demodata;
UPDATE messung SET q_bpegel = q_bpegel*:qfac;
\c d4e_demodata;

-- alter flow velocities
-- \set vfac 10+10*random();
BEGIN;
UPDATE flow_velocity_model_values SET (total_channel, main_channel) = 
    (total_channel*:vfac, main_channel*:vfac);
UPDATE flow_velocity_measure_values SET v = v*:vfac;
COMMIT;

-- alter sediment yields
-- \set sfac 10+10*random();
UPDATE sediment_yield_values SET value = value*:sfac;
