DELETE FROM rivers WHERE name <> 'Elbe';

-- master data
DELETE FROM ranges 
    WHERE b <= (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
        OR a >= (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken')
	OR (b IS NULL AND a < (SELECT a FROM gauges JOIN ranges r ON range_id=r.id 
            WHERE name='Torgau'));
-- the following seems to be better done by truncate_ranges()
--        OR (a < (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
--            AND 
--            b >= (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken'));

-- the following might violate UNIQUE(river_id, a, b)
-- UPDATE ranges SET a=(SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
--     WHERE a < (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
--         AND NOT b IN (SELECT b FROM ranges 
--             WHERE a=(SELECT a FROM gauges JOIN ranges r ON range_id=r.id 
--                 WHERE name='Torgau'));
-- UPDATE ranges SET b=(SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken')
--     WHERE b > (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken')
--         AND NOT a IN (SELECT a FROM ranges 
--             WHERE b=(SELECT b FROM gauges JOIN ranges r ON range_id=r.id 
--                 WHERE name='Aken'));
-- the following function should do better:
\i ./truncate_ranges.sql
SELECT truncate_ranges();

DELETE FROM attributes WHERE id NOT IN (SELECT attribute_id FROM annotations);
DELETE FROM positions WHERE id NOT IN (SELECT position_id FROM annotations);
DELETE FROM edges WHERE id NOT IN (SELECT edge_id FROM annotations);
DELETE FROM annotation_types WHERE id NOT IN (SELECT type_id FROM annotations);

-- hydrologic data
DELETE FROM gauges WHERE station NOT BETWEEN 
       (SELECT station FROM gauges WHERE name='Torgau')
       AND (SELECT station FROM gauges WHERE name='Aken');

DELETE FROM named_main_values 
    WHERE id NOT IN (SELECT named_value_id FROM main_values);

DELETE FROM wst_column_values WHERE position NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');
DELETE FROM wst_columns WHERE id NOT IN (select wst_column_id from wst_column_values);

DELETE FROM hyk_entries WHERE km NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

-- morphologic data
DELETE FROM bed_height_single_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM bed_height_epoch_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM sediment_density_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM morphologic_width_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM flow_velocity_model_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM flow_velocity_measure_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM sediment_yield_values WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM measurement_station WHERE station NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');


-- geodetic data
DELETE FROM cross_section_lines WHERE km NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM river_axes_km WHERE km NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM cross_section_tracks WHERE km NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM buildings WHERE NOT ST_intersects(geom, 
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));

DELETE FROM fixpoints WHERE km NOT BETWEEN
       (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau')
       AND (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');

DELETE FROM jetties
    WHERE NOT geom && ST_convexhull(
        (SELECT ST_collect(geom) FROM cross_section_tracks));
-- there are none in this area

DELETE FROM flood_marks WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));

UPDATE river_axes SET geom = ST_multi(ST_intersection(geom, 
    (SELECT ST_expand(ST_collect(geom), 0) FROM cross_section_tracks)));

UPDATE floodplain SET geom = ST_intersection(geom, 
    (SELECT ST_expand(ST_collect(geom), 0) FROM cross_section_tracks));
--    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));
-- results in a MULTIPOLYGON

-- Create an index to speed up the following operation
CREATE INDEX floodmaps_idx ON floodmaps USING gist (geom);
VACUUM ANALYZE floodmaps (geom);
DELETE FROM floodmaps where geom && 
    st_setsrid(ST_point(3773728.7138523096,5718636.158959819), 31467);
-- there is a topological error around the given point in 
-- at least one of the removed geometries.
-- removing them makes the next statement work
DELETE FROM floodmaps WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));
UPDATE floodmaps SET geom = ST_multi(ST_intersection(geom, 
    (SELECT ST_expand(ST_collect(geom), 10000) FROM cross_section_tracks)));

DELETE FROM hws_lines WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));
UPDATE hws_lines SET geom = ST_multi(ST_intersection(geom, 
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks))));

DELETE FROM hws_points WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));

DELETE FROM hydr_boundaries WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));
UPDATE hydr_boundaries SET geom = ST_multi(ST_intersection(geom, 
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks))));

DELETE FROM hydr_boundaries_poly WHERE NOT ST_intersects(geom,
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks)));
UPDATE hydr_boundaries_poly SET geom = ST_multi(ST_intersection(geom, 
    ST_convexhull((SELECT ST_collect(geom) FROM cross_section_tracks))));

DELETE FROM dem WHERE path LIKE '%tnxy.adf';
UPDATE dem SET (name, path) = ('DGM1', './dem1.grd')
    WHERE path LIKE '%m_09920_20300.grd';
UPDATE dem SET (name, path) = ('DGM2', './dem2.grd')
    WHERE path LIKE '%m_20200_29980.grd';
