-- truncate ranges to the range from Torgau to Aken
CREATE FUNCTION truncate_ranges() returns void AS $$
DECLARE rid INTEGER;
DECLARE min_a NUMERIC;
DECLARE max_b NUMERIC;
DECLARE ra NUMERIC;
DECLARE rb NUMERIC;
DECLARE new_id INTEGER;
BEGIN
min_a := (SELECT a FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Torgau');
max_b := (SELECT b FROM gauges JOIN ranges r ON range_id=r.id WHERE name='Aken');
FOR rid IN SELECT id FROM ranges LOOP
    ra := (SELECT a FROM ranges WHERE id=rid);
    rb := (SELECT b FROM ranges WHERE id=rid);

    -- in case range is between Torgau and Aken, do nothing
    CONTINUE WHEN ra >= min_a AND rb <= max_b;

    -- else, truncate range
    IF ra < min_a THEN 
        ra := min_a;
    END IF;
    IF rb > max_b THEN 
        rb := max_b;
    END IF;
    IF EXISTS(SELECT * FROM ranges WHERE a = ra AND b = rb) THEN
            -- use existing range instead
            new_id := (SELECT id FROM ranges WHERE a = ra AND b = rb);
            UPDATE annotations SET range_id = new_id WHERE range_id = rid;
            UPDATE gauges SET range_id = new_id WHERE range_id = rid;
            UPDATE wst_q_ranges SET range_id = new_id WHERE range_id = rid;
            UPDATE dem SET range_id = new_id WHERE range_id = rid;
            UPDATE bed_height_single SET range_id = new_id WHERE range_id = rid;
            UPDATE bed_height_epoch SET range_id = new_id WHERE range_id = rid;
            UPDATE measurement_station SET range_id = new_id WHERE range_id = rid;
            DELETE FROM ranges WHERE id = rid;
        ELSE
            -- truncate range
            UPDATE ranges SET (a,b) = (ra,rb) WHERE id = rid;
        END IF;
END LOOP;
END;
$$ LANGUAGE plpgsql;
